@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 1;
 __END__
@@ -75,6 +75,10 @@ of running, the test suite is killed and C<n/a timeout> is reported.
 
 Alexandr Ciornii (chorny)
 
+Tim Teasdale (hooverbag)
+
+Patricio Valle (pvallev)
+
 =head1 AUTHOR
 
 Viacheslav Tykhanovskyi, E<lt>viacheslav.t@gmail.comE<gt>
